RealityEngine

Struct RealityEngine 

pub struct RealityEngine {
    pub deployment_store: DeploymentStore,
    pub environment_store: EnvironmentStore,
    pub resource_store: ResourceStore,
    pub reality_store: RealityStore,
    pub topology_store: TopologyStore,
    pub temporal_store: TemporalStore,
    pub stakes_store: StakesStore,
    pub coherence_store: CoherenceStore,
    pub indexes: RealityIndexes,
    /* private fields */
}
The main reality engine combining write and query capabilities.

Fields

deployment_store: DeploymentStoreenvironment_store: EnvironmentStoreresource_store: ResourceStorereality_store: RealityStoretopology_store: TopologyStoretemporal_store: TemporalStorestakes_store: StakesStorecoherence_store: CoherenceStoreindexes: RealityIndexes

Implementations

Source

impl RealityEngine

pub fn new() -> Self

Create a new empty reality engine.

pub fn writer(&mut self) -> WriteEngine<'_>

Get a write engine handle.

pub fn reader(&self) -> QueryEngine<'_>

Get a query engine handle.

pub fn is_dirty(&self) -> bool

Whether the engine has unsaved changes.

pub fn mark_dirty(&mut self)

Mark the engine as dirty (has unsaved changes).

pub fn mark_clean(&mut self)

Mark the engine as clean (all changes saved).

pub fn incarnation_id(&self) -> Option<IncarnationId>

Get the current incarnation ID if initialized.

pub fn is_initialized(&self) -> bool

Check if the engine has been initialized with a deployment soul.