pub struct RealityEngine {
pub deployment_store: DeploymentStore,
pub environment_store: EnvironmentStore,
pub resource_store: ResourceStore,
pub reality_store: RealityStore,
pub topology_store: TopologyStore,
pub temporal_store: TemporalStore,
pub stakes_store: StakesStore,
pub coherence_store: CoherenceStore,
pub indexes: RealityIndexes,
/* private fields */
}Expand description
The main reality engine combining write and query capabilities.
Fields
deployment_store: DeploymentStoreenvironment_store: EnvironmentStoreresource_store: ResourceStorereality_store: RealityStoretopology_store: TopologyStoretemporal_store: TemporalStorestakes_store: StakesStorecoherence_store: CoherenceStoreindexes: RealityIndexesImplementations
Sourceimpl RealityEngine
impl RealityEngine
Sourcepub fn writer(&mut self) -> WriteEngine<'_>
pub fn writer(&mut self) -> WriteEngine<'_>
Get a write engine handle.
Sourcepub fn reader(&self) -> QueryEngine<'_>
pub fn reader(&self) -> QueryEngine<'_>
Get a query engine handle.
Sourcepub fn mark_dirty(&mut self)
pub fn mark_dirty(&mut self)
Mark the engine as dirty (has unsaved changes).
Sourcepub fn mark_clean(&mut self)
pub fn mark_clean(&mut self)
Mark the engine as clean (all changes saved).
Sourcepub fn incarnation_id(&self) -> Option<IncarnationId>
pub fn incarnation_id(&self) -> Option<IncarnationId>
Get the current incarnation ID if initialized.
Sourcepub fn is_initialized(&self) -> bool
pub fn is_initialized(&self) -> bool
Check if the engine has been initialized with a deployment soul.